summaryrefslogtreecommitdiff
path: root/ubi-utils/include
diff options
context:
space:
mode:
authorArtem Bityutskiy <Artem.Bityutskiy@nokia.com>2009-04-20 13:03:21 +0300
committerArtem Bityutskiy <Artem.Bityutskiy@nokia.com>2009-04-20 16:29:39 +0300
commitfc85dfd76f97387ccddb46861effa6c386901218 (patch)
tree266019e4e57901242c7f84e559a0aa3aa7454652 /ubi-utils/include
parentb03c80c7d84e14ab1a28311db4bc7eb08948c569 (diff)
libmtd: rename mtd_get_info
Rename 'mtd_get_info()' into 'mtd_get_dev_info()' to be consistent to libubi. Signed-off-by: Artem Bityutskiy <Artem.Bityutskiy@nokia.com>
Diffstat (limited to 'ubi-utils/include')
-rw-r--r--ubi-utils/include/libmtd.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ubi-utils/include/libmtd.h b/ubi-utils/include/libmtd.h
index 9c7a6e3..f2f4da2 100644
--- a/ubi-utils/include/libmtd.h
+++ b/ubi-utils/include/libmtd.h
@@ -38,7 +38,7 @@ extern "C" {
* @eb_cnt: count of eraseblocks
* @eb_size: eraseblock size
* @min_io_size: minimum input/output unit size
- * @subpage_size: sub-page size (not set by 'mtd_get_info()'!!!)
+ * @subpage_size: sub-page size
* @rdonly: non-zero if the device is read-only
* @allows_bb: non-zero if the MTD device may have bad eraseblocks
*/
@@ -59,7 +59,7 @@ struct mtd_info
};
/**
* mtd_get_info - get information about an MTD device.
* @node: name of the MTD device node
* @mtd: the MTD device information is returned here
*
@@ -67,7 +67,7 @@ struct mtd_info
* node file and saves this information in the @mtd object. Returns %0 in case
* of success and %-1 in case of failure.
*/
-int mtd_get_info(const char *node, struct mtd_info *mtd);
+int mtd_get_dev_info(const char *node, struct mtd_info *mtd);
/**
* mtd_erase - erase an eraseblock.
@@ -59,7 +59,7 @@ struct mtd_info
};
/**
- * mtd_get_info - get information about an MTD device.
+ * mtd_get_dev_info - get information about an MTD device.
* @node: name of the MTD device node
* @mtd: the MTD device information is returned here